@@ -2,8 +2,7 @@ package Elive::Struct;
 use warnings; use strict;
 
 use Mouse;
-use Elive;
-use base qw{Elive};
+use parent qw{Elive};
 
 use Elive::Array;
 use Elive::Util;
@@ -184,7 +183,7 @@ sub entity_name {
 
 # _alias, _get_aliases
 #
-#    MyApp::Entity::Meeting->_set_data_mapping(requiredSeats => 'seats');
+#    MyApp::Entity::Meeting->_alias(requiredSeats => 'seats');
 #
 # Return or set data mappings.
 #
@@ -213,10 +212,10 @@ sub _alias {
 	if $aliases->{$from};
 
     die "$entity_class: can't alias $from it's already a property!"
-	if $entity_class->meta->get_attribute($from);
+	if $entity_class->meta->find_attribute_by_name($from);
 
     die "$entity_class: attempt to alias $from to non-existant property $to - check spelling and declaration order"
-	unless $entity_class->meta->get_attribute($to);
+	unless $entity_class->meta->find_attribute_by_name($to);
 
     $opt{to} = $to;
     $aliases->{$from} = \%opt;
@@ -225,7 +224,6 @@ sub _alias {
 }
 
 sub _get_aliases {
-
     my $entity_class = shift;
 
     my $aliases = $entity_class->_aliases;
@@ -288,7 +286,7 @@ sub params {
 
 =head2 derivable
 
-    Setter/getter for derivable field(s) for this entity class
+Setter/getter for derivable field(s) for this entity class
 
 =cut
 
@@ -349,7 +347,7 @@ sub _ordered_attributes {
 
     my $meta = $class->meta;
 
-    return map {$meta->get_attribute($_)} ($class->_ordered_attribute_names);
+    return map {$meta->find_attribute_by_name($_)} ($class->_ordered_attribute_names);
 }
 
 sub _cmp_col {
@@ -444,7 +442,7 @@ sub property_types {
     my @atts = $meta->get_attribute_list;
 
     return {
-	map {$_ => $meta->get_attribute($_)->type_constraint} @atts
+	map {$_ => $meta->find_attribute_by_name($_)->type_constraint} @atts
     };
 }
 
@@ -460,8 +458,10 @@ Return a hashref of documentation for properties
 sub property_doco {
     my $class = shift;
 
+    my @atts = $class->_ordered_attributes;
+
     return {
-	map {$_->name => $_->{documentation}} ($class->_ordered_attributes)
+	map {$_->name => $_->{documentation}} @atts
     };
 }
 
@@ -509,7 +509,7 @@ sub set {
 	}
 
 	my $meta = $self->meta;
-	my $attribute =  $meta->get_attribute($_);
+	my $attribute =  $meta->find_attribute_by_name($_);
 	my $value = $data{$_};
 
 	if (defined $value) {
