@@ -6,11 +6,11 @@ use Mouse::Util::TypeConstraints;
 
 extends 'Elive::Struct';
 
+use Elive::DAO;
 use Elive::Entity::Meeting;
 use Elive::Entity::ServerParameters;
 use Elive::Entity::MeetingParameters;
 use Elive::Entity::ParticipantList;
-use Elive::Util;
 use Carp;
 
 __PACKAGE__->entity_name('Session');
@@ -20,6 +20,8 @@ __PACKAGE__->primary_key('id');
 __PACKAGE__->_alias(meetingId => 'id');
 __PACKAGE__->_alias(sessionId => 'id');
 
+our %handled = (meetingId => 1);
+
 our %delegates = (
     meeting => 'Elive::Entity::Meeting',
     meeting_parameters => 'Elive::Entity::MeetingParameters',
@@ -27,13 +29,10 @@ our %delegates = (
     participant_list => 'Elive::Entity::ParticipantList',
     );
 
-our %handled = (meetingId => 1);
-
 foreach my $prop (sort keys %delegates) {
     my $class = $delegates{$prop};
-    my $aliases = $class->_get_aliases;
-    my @delegates = grep {!$handled{$_}++} ($class->properties, $class->derivable, sort keys %$aliases);
-    push (@delegates, qw{buildJNLP check_preload add_preload remove_preload is_participant is_moderator list_preloads list_recordings})
+    my @delegates = grep {!$handled{$_}++} ($class->properties, $class->derivable);
+    push (@delegates, qw{buildJNLP add_preload remove_preload is_participanr us_moderator list_preloads list_recordings})
 	if $prop eq 'meeting';
 
     has $prop
@@ -50,7 +49,8 @@ Elive::View::Session - Session view class
 
 =head1 DESCRIPTION
 
-A session is a consolidated view of meetings, meeting parameters, server parameters and participants.
+A session is a consolidated view of meetings, meeting participants, server
+parameters and participants.
 
 =head1 METHODS
 
@@ -89,16 +89,6 @@ Creates a new session on an Elluminate server.
 
     my $session = Elive::View::Session->insert( \%session_data );
 
-A series of sesions can be created using the C<recurrenceCount> and C<recurrenceDays> parameters.
-
-    #
-    # create three weekly sessions
-    #
-    my @sessions = Elive::View::Session->insert({
-                            ...,
-                            recurrenceCount => 3,
-                            recurrenceDays  => 7,
-                        });
 =cut
 
 sub insert {
@@ -115,29 +105,20 @@ sub insert {
 	$_ => delete $data{$_}
     } @meeting_props;
 
+    my $meeting = Elive::Entity::Meeting->insert(\%meeting_data, %opts);
+
+    my $self = bless {id => $meeting->meetingId,
+		      meeting => $meeting}, $class;
+
+    $self->connection( $meeting->connection );
     #
-    # recurrenceCount, and recurrenceDays may result in multiple meetings
+    # from here on in, it's just a matter of updating attributes owned by
+    # the other entities
     #
-    my @meetings = Elive::Entity::Meeting->insert(\%meeting_data, %opts);
+    $self->update(\%data, %opts)
+	if keys %data;
 
-    my @objs = map {
-	my $meeting = $_;
-
-	my $self = bless {id => $meeting->meetingId,
-			  meeting => $meeting}, $class;
-	$self->connection( $meeting->connection );
-	#
-	# from here on in, it's just a matter of updating attributes owned by
-	# the other entities. We need to do this for each meeting instance
-	#
-	$self->update(\%data, %opts)
-	    if keys %data;
-
-	$self;
-
-    } @meetings;
-
-    return wantarray? @objs : $objs[0];
+    return $self;
 }
 
 =head2 update
@@ -158,8 +139,6 @@ sub update {
     my %data = %{ shift() };
     my %opts = @_;
 
-    my $preloads = delete $data{add_preload};
-
    foreach my $delegate (sort keys %delegates) {
 
 	my $delegate_class = $delegates{$delegate};
@@ -172,15 +151,6 @@ sub update {
 	$self->$delegate->update( \%delegate_data, %opts );
     }
 
-    if ($preloads) {
-	$preloads = [$preloads]
-	    unless Elive::Util::_reftype($preloads) eq 'ARRAY';
-
-	foreach my $preload (@$preloads) {
-	    $self->meeting->add_preload( $preload );
-	}
-    }
-
     return $self;
 }
 
@@ -197,7 +167,7 @@ sub retrieve {
     my $id = shift;
     my %opt = @_;
     ($id) = @$id if ref($id);
-    my $self = bless {id => Elive::Util::string($id)}, $class;
+    my $self = bless {id => $id}, $class;
 
     for ($opt{connection}) {
 	$self->connection($_) if $_;
@@ -214,7 +184,15 @@ List all sessions that match a given critera:
 
 Note:
 
-You can only select on core meeting properties (C<name>, C<start>, C<end>, C<password>, C<deleted>, C<faciltatorId>, C<privateMeeting>, C<allModerators>, C<restrictedMeeting> and C<adapter>).  Access to other properties requires a secondary fetch and may be slower.
+=over 4
+
+=item * core meeting properties are: name, start, end, password, deleted, faciltatorId, privateMeeting, allModerators, restrictedMeeting and adapter.
+
+=item * you can only select on core meeting properties
+
+=item * access to other properties requires a secondary fetch and may be slower.
+
+=back
 
 =cut
 
@@ -267,12 +245,9 @@ sub _owned_by {
 
     my $delegate_types = $delegate_class->property_types;
     my $delegate_aliases = $delegate_class->_aliases;
-    my %delegate_params = $delegate_class->params;
 
     return grep {exists $delegate_types->{$_}
-		 || exists $delegate_aliases->{$_}
-		 || exists $delegate_params{$_};
-    } @props
+		 or exists $delegate_aliases->{$_}} @props
 }
 
 sub set {
@@ -299,7 +274,7 @@ sub properties {
 
     my %seen = (meetingId => 1);
 
-    my @all_properties = sort grep {! $seen{$_}++} (
+    my @all_properties = grep {! $seen{$_}++} (
 	'id',
 	map {$_->properties} sort values %delegates,
     );
@@ -322,14 +297,6 @@ sub property_types {
     return \%property_types;
 }
 
-sub property_doco {
-    my $class = shift;
-
-    return {
-	map { %{$_->property_doco} } sort values %delegates,
-    };
-}
-
 sub derivable {
     my $class = shift;
     return (
@@ -337,7 +304,7 @@ sub derivable {
 	);
 }
 
-=head1 SEE ALSO
+=head2 SEE ALSO
 
 L<Elive::Entity::Meeting>
 L<Elive::Entity::MeetingParameters>
